public inbox for isar-users@googlegroups.com
 help / color / mirror / Atom feed
* [PATCH] meta: correct CamelCase spelling of APT options
@ 2019-09-17 14:35 Henning Schild
  2019-10-08 10:59 ` Baurzhan Ismagulov
  0 siblings, 1 reply; 2+ messages in thread
From: Henning Schild @ 2019-09-17 14:35 UTC (permalink / raw)
  To: isar-users; +Cc: Henning Schild

From: Henning Schild <henning.schild@siemens.com>

This is a purely cosmetic change aligning us with the spelling used in
the documentation, no functional change. The other spelling obviously
worked as well, but better stick to what the docs say.

Signed-off-by: Henning Schild <henning.schild@siemens.com>
---
 meta/classes/dpkg-base.bbclass                  | 4 ++--
 meta/classes/image-tools-extension.bbclass      | 4 ++--
 meta/classes/rootfs.bbclass                     | 4 ++--
 meta/recipes-devtools/buildchroot/files/deps.sh | 8 ++++----
 meta/recipes-kernel/linux/linux-custom.inc      | 4 ++--
 5 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/meta/classes/dpkg-base.bbclass b/meta/classes/dpkg-base.bbclass
index 39c8acb..99f3edf 100644
--- a/meta/classes/dpkg-base.bbclass
+++ b/meta/classes/dpkg-base.bbclass
@@ -32,8 +32,8 @@ do_apt_fetch() {
 	dpkg_do_mounts
 	E="${@ bb.utils.export_proxies(d)}"
 	sudo -E chroot ${BUILDCHROOT_DIR} /usr/bin/apt-get update \
-		-o Dir::Etc::sourcelist="sources.list.d/isar-apt.list" \
-		-o Dir::Etc::sourceparts="-" \
+		-o Dir::Etc::SourceList="sources.list.d/isar-apt.list" \
+		-o Dir::Etc::SourceParts="-" \
 		-o APT::Get::List-Cleanup="0"
 	sudo -E chroot --userspec=$( id -u ):$( id -g ) ${BUILDCHROOT_DIR} \
 		sh -c 'cd ${PP} && apt-get -y source ${SRC_APT}'
diff --git a/meta/classes/image-tools-extension.bbclass b/meta/classes/image-tools-extension.bbclass
index ca94d49..2d8a777 100644
--- a/meta/classes/image-tools-extension.bbclass
+++ b/meta/classes/image-tools-extension.bbclass
@@ -27,8 +27,8 @@ do_install_imager_deps() {
     E="${@bb.utils.export_proxies(d)}"
     sudo -E chroot ${BUILDCHROOT_DIR} sh -c ' \
         apt-get update \
-            -o Dir::Etc::sourcelist="sources.list.d/isar-apt.list" \
-            -o Dir::Etc::sourceparts="-" \
+            -o Dir::Etc::SourceList="sources.list.d/isar-apt.list" \
+            -o Dir::Etc::SourceParts="-" \
             -o APT::Get::List-Cleanup="0"
         apt-get -o Debug::pkgProblemResolver=yes --no-install-recommends -y \
             --allow-unauthenticated --allow-downgrades install \
diff --git a/meta/classes/rootfs.bbclass b/meta/classes/rootfs.bbclass
index c7e0435..83c2475 100644
--- a/meta/classes/rootfs.bbclass
+++ b/meta/classes/rootfs.bbclass
@@ -95,8 +95,8 @@ ROOTFS_INSTALL_COMMAND += "rootfs_install_pkgs_update"
 rootfs_install_pkgs_update[weight] = "5"
 rootfs_install_pkgs_update() {
     sudo -E chroot '${ROOTFSDIR}' /usr/bin/apt-get update \
-        -o Dir::Etc::sourcelist="sources.list.d/isar-apt.list" \
-        -o Dir::Etc::sourceparts="-" \
+        -o Dir::Etc::SourceList="sources.list.d/isar-apt.list" \
+        -o Dir::Etc::SourceParts="-" \
         -o APT::Get::List-Cleanup="0"
 }
 
diff --git a/meta/recipes-kernel/linux/linux-custom.inc b/meta/recipes-kernel/linux/linux-custom.inc
index ee5f20c..007d9e2 100644
--- a/meta/recipes-kernel/linux/linux-custom.inc
+++ b/meta/recipes-kernel/linux/linux-custom.inc
@@ -31,8 +31,8 @@ do_install_builddeps() {
 	E="${@ bb.utils.export_proxies(d)}"
 	sudo -E chroot ${BUILDCHROOT_DIR} \
 		apt-get update \
-			-o Dir::Etc::sourcelist="sources.list.d/isar-apt.list" \
-			-o Dir::Etc::sourceparts="-" \
+			-o Dir::Etc::SourceList="sources.list.d/isar-apt.list" \
+			-o Dir::Etc::SourceParts="-" \
 			-o APT::Get::List-Cleanup="0"
 	sudo -E chroot ${BUILDCHROOT_DIR} \
 		apt-get install \
diff --git a/meta/recipes-devtools/buildchroot/files/deps.sh b/meta/recipes-devtools/buildchroot/files/deps.sh
index 1963943..545adcd 100644
--- a/meta/recipes-devtools/buildchroot/files/deps.sh
+++ b/meta/recipes-devtools/buildchroot/files/deps.sh
@@ -16,13 +16,13 @@ install_cmd="apt-get -o Debug::pkgProblemResolver=yes --no-install-recommends \
 
 # Make sure that we have latest isar-apt content.
 # Options meaning:
 #   Dir::Etc::sourcelist - specifies which source to be used
 #   Dir::Etc::sourceparts - disables looking for the other sources
 #   APT::Get::List-Cleanup - do not erase obsolete packages list for
 #                            upstream in '/var/lib/apt/lists'
 apt-get update \
-    -o Dir::Etc::sourcelist="sources.list.d/isar-apt.list" \
-    -o Dir::Etc::sourceparts="-" \
+    -o Dir::Etc::SourceList="sources.list.d/isar-apt.list" \
+    -o Dir::Etc::SourceParts="-" \
     -o APT::Get::List-Cleanup="0"
 
 # Install all build deps
@@ -16,13 +16,13 @@ install_cmd="apt-get -o Debug::pkgProblemResolver=yes --no-install-recommends \
 # Make sure that we have latest isar-apt content.
 # Options meaning:
-#   Dir::Etc::sourcelist - specifies which source to be used
-#   Dir::Etc::sourceparts - disables looking for the other sources
+#   Dir::Etc::SourceList - specifies which source to be used
+#   Dir::Etc::SourceParts - disables looking for the other sources
 #   APT::Get::List-Cleanup - do not erase obsolete packages list for
 #                            upstream in '/var/lib/apt/lists'
-- 
2.21.0


^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: [PATCH] meta: correct CamelCase spelling of APT options
  2019-09-17 14:35 [PATCH] meta: correct CamelCase spelling of APT options Henning Schild
@ 2019-10-08 10:59 ` Baurzhan Ismagulov
  0 siblings, 0 replies; 2+ messages in thread
From: Baurzhan Ismagulov @ 2019-10-08 10:59 UTC (permalink / raw)
  To: isar-users

On Tue, Sep 17, 2019 at 04:35:50PM +0200, Henning Schild wrote:
> This is a purely cosmetic change aligning us with the spelling used in
> the documentation, no functional change. The other spelling obviously
> worked as well, but better stick to what the docs say.

Thanks, applied to next.

With kind regards,
Baurzhan.

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2019-10-08 10:59 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-09-17 14:35 [PATCH] meta: correct CamelCase spelling of APT options Henning Schild
2019-10-08 10:59 ` Baurzhan Ismagulov

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox